@@ -13,16 +13,17 @@ def check_latest_version():
     config = yaml_parser.parse_config()
 
     package_name = config['static']['app_name']
-    print('package_name is: ' + package_name)
+    # print('package_name is: ' + package_name)
 
     current_version = _version.__version__
+    
     pypi = PyPISimple()
-
     page = pypi.get_project_page(package_name)
-    latest_version = page.packages[0].version
-    package_url = page.packages[0].url
-    print('latest_version is: ' + latest_version)
-    print ('package_url is: ' + package_url)
+    latest_version = page.packages[-1].version
+    
+    # package_url = page.packages[-1].url
+    # print('latest_version is: ' + latest_version)
+    # print ('package_url is: ' + package_url)
     if current_version == latest_version:
         logger.log(message="Latest version detected, proceeding.", log_level="info", to_file=True, to_terminal=False)
     else:
